@@ -126,8 +126,6 @@ void *uu_FileCBArg = NULL;
 void *uu_FFCBArg   = NULL;
 void *uu_FNCBArg;
 
-int uu_autocheck = 1;           /* call UUCheckGlobaList after every part */
-
 /* I/O buffer sizes */
 int uu_rbuf = 0;
 int uu_wbuf = 0;
@@ -242,7 +240,7 @@ static allomap toallocate[] = {
   { &uuestr_itemp,       256 },  /* from uuencode.c:UUEncodeStream() */
   { &uuestr_otemp,      1024 },
   { &uulib_msgstring,   1024 },  /* from uulib.c:UUMessage() */
-  { &uuncdl_fulline,    1201 },  /* from uunconc.c:UUDecodeLine() */
+  { &uuncdl_fulline,    1200 },  /* from uunconc.c:UUDecodeLine() */
   { &uuncdp_oline,      3600 },  /* from uunconc.c:UUDecodePart() */
   { &uunconc_UUxlat,     256 * sizeof (int) },  /* from uunconc.c:toplevel */
   { &uunconc_UUxlen,      64 * sizeof (int) },
@@ -254,10 +252,10 @@ static allomap toallocate[] = {
   { &uuscan_shlline2,   1024 },  /* from uuscan.c:ScanHeaderLine() */
   { &uuscan_pvvalue,     300 },  /* from uuscan.c:ParseValue() */
   { &uuscan_phtext,      300 },  /* from uuscan.c:ParseHeader() */
-  { &uuscan_sdline,     1025 },  /* from uuscan.c:ScanData(), +1 for UURepairData */
+  { &uuscan_sdline,      300 },  /* from uuscan.c:ScanData() */
   { &uuscan_sdbhds1,     300 },
   { &uuscan_sdbhds2,     300 },
-  { &uuscan_spline,     1024 },  /* from uuscan.c:ScanPart() */
+  { &uuscan_spline,      300 },  /* from uuscan.c:ScanPart() */
   { &uuutil_bhwtmp,      300 },  /* from uuutil.c:UUbhwrite() */
   { NULL, 0 }
 };
@@ -275,7 +273,7 @@ UUMessage (va_alist)
   va_dcl
 #endif
 {
-  int msgofs;
+  char *msgptr;
 #if defined(STDC_HEADERS) || defined(HAVE_STDARG_H)
   va_list ap;
 
@@ -293,16 +291,16 @@ UUMessage (va_alist)
 #endif
 
   if (uu_debug) {
-    snprintf (uulib_msgstring, 1024,  "%s(%d): %s", file, line, msgnames[level]);
-    msgofs = strlen (uulib_msgstring);
+    sprintf (uulib_msgstring, "%s(%d): %s", file, line, msgnames[level]);
+    msgptr = uulib_msgstring + strlen (uulib_msgstring);
   }
   else {
-    snprintf (uulib_msgstring, 1024, "%s", msgnames[level]);
-    msgofs = strlen (uulib_msgstring);
+    sprintf (uulib_msgstring, "%s", msgnames[level]);
+    msgptr = uulib_msgstring + strlen (uulib_msgstring);
   }
 
   if (uu_MsgCallback && (level>UUMSG_NOTE || uu_verbose)) {
-    vsnprintf (uulib_msgstring + msgofs, 1024 - msgofs, format, ap);
+    vsprintf (msgptr, format, ap);
 
     (*uu_MsgCallback) (uu_MsgCBArg, uulib_msgstring, level);
   }
@@ -519,10 +517,6 @@ UUGetOption (int option, int *ivalue, char *cvalue, int clength)
     if (ivalue) *ivalue = uu_dotdot;
     result = uu_dotdot;
     break;
-  case UUOPT_AUTOCHECK:
-    if (ivalue) *ivalue = uu_autocheck;
-    result = uu_autocheck;
-    break;
   default:
     return -1;
   }
@@ -592,9 +586,6 @@ UUSetOption (int option, int ivalue, char *cvalue)
   case UUOPT_DOTDOT:
     uu_dotdot = ivalue;
     break;
-  case UUOPT_AUTOCHECK:
-    uu_autocheck = ivalue;
-    break;
   default:
     return UURET_ILLVAL;
   }
@@ -779,7 +770,7 @@ UULoadFileWithPartNo (char *filename, char *fileid, int delflag, int partno, int
     /* 
      * Peek file, or some systems won't detect EOF
      */
-    res = _FP_fgetc (datei);
+    res = fgetc (datei);
     if (feof (datei) || ferror (datei))
       break;
     else
@@ -793,7 +784,7 @@ UULoadFileWithPartNo (char *filename, char *fileid, int delflag, int partno, int
 		     uustring (S_READ_ERROR), filename,
 		     strerror (uu_errno));
 
-	if (uu_autocheck) UUCheckGlobalList ();
+	UUCheckGlobalList ();
 	progress.action = 0;
 	fclose (datei);
         UUCLRBUF (uu_rbuf, datei_buf);
@@ -806,7 +797,7 @@ UULoadFileWithPartNo (char *filename, char *fileid, int delflag, int partno, int
       UUMessage (uulib_id, __LINE__, UUMSG_ERROR,
 		 uustring (S_READ_ERROR), filename,
 		 strerror (uu_errno = errno));
-      if (uu_autocheck) UUCheckGlobalList ();
+      UUCheckGlobalList ();
       progress.action = 0;
       fclose (datei);
       UUCLRBUF (uu_rbuf, datei_buf);
@@ -875,7 +866,7 @@ UULoadFileWithPartNo (char *filename, char *fileid, int delflag, int partno, int
       UUkillfile (fload);
 
       if (res != UURET_NODATA) {
-	if (uu_autocheck) UUCheckGlobalList ();
+	UUCheckGlobalList ();
 	progress.action = 0;
 	fclose (datei);
         UUCLRBUF (uu_rbuf, datei_buf);
@@ -898,18 +889,16 @@ UULoadFileWithPartNo (char *filename, char *fileid, int delflag, int partno, int
     if (uu_fast_scanning && sr != UURET_CONT)
       break;
   }
-
   if (ferror (datei)) {
     UUMessage (uulib_id, __LINE__, UUMSG_ERROR,
 	       uustring (S_READ_ERROR), filename,
 	       strerror (uu_errno = errno));
-    if (uu_autocheck) UUCheckGlobalList ();
+    UUCheckGlobalList ();
     progress.action = 0;
     fclose (datei);
     UUCLRBUF (uu_rbuf, datei_buf);
     return UURET_IOERR;
   }
-
   fclose (datei);
   UUCLRBUF (uu_rbuf, datei_buf);
 
@@ -918,7 +907,7 @@ UULoadFileWithPartNo (char *filename, char *fileid, int delflag, int partno, int
 	       uustring (S_NO_DATA_FOUND), filename);
 
   progress.action = 0;
-  if (uu_autocheck) UUCheckGlobalList ();
+  UUCheckGlobalList ();
 
   return UURET_OK;
 }
@@ -992,10 +981,10 @@ UUDecodeFile (uulist *thefile, char *destname)
   if (destname)
     strcpy (uugen_fnbuffer, destname);
   else {
-    char *fname = UUFNameFilter (thefile->filename ? thefile->filename : "unknown.xxx");
     sprintf (uugen_fnbuffer, "%.1024s%.3071s",
-	     uusavepath ? uusavepath : "",
-             fname ? fname : "unknown.xxx");
+	     (uusavepath)?uusavepath:"",
+	     UUFNameFilter ((thefile->filename)?
+			    thefile->filename:"unknown.xxx"));
   }
 
   /*
